---
title: Xamarin.Android warning XA0036
description: XA0036 warning code
ms.date: 06/17/2020
---
# Xamarin.Android warning XA0036

## Issue

The `$(AndroidSupportedAbis)` MSBuild property is no longer supported
in .NET 5 and higher.

## Solution

Open the project file [in Visual Studio][edit-project-files] or
another text editor and remove `<AndroidSupportedAbis/>`. Use the
`RuntimeIdentifiers` MSBuild property instead:

```xml
<PropertyGroup>
  <RuntimeIdentifiers>android.21-arm;android.21-arm64;android.21-x86;android.21-x64</RuntimeIdentifiers>
</PropertyGroup>
```

See the Microsoft documentation on [runtime identifiers][rids] for more
information.

[edit-project-files]: https://docs.microsoft.com/visualstudio/msbuild/visual-studio-integration-msbuild#edit-project-files-in-visual-studio
[rids]: https://docs.microsoft.com/dotnet/core/rid-catalog

## Example messages

```
warning XA0036: The 'AndroidSupportedAbis' MSBuild property is no longer supported. Edit the project file in a text editor, remove any uses of 'AndroidSupportedAbis', and use the 'RuntimeIdentifiers' MSBuild property instead.
```
