### Smaller app package sizes

This version introduces compression of managed assemblies by default for Release
configuration builds, resulting in significantly smaller APK and App Bundle
sizes.  Assemblies are compressed with the [LZ4][lz4] algorithm during builds
and then decompressed on device during app startup.

For a small example Xamarin.Forms application, this reduced the APK size from
about 23 megabytes to about 17 megabytes while only increasing the time to
display the first page of the app from about 780 milliseconds to about 790
milliseconds in the least favorable configuration.

If needed, the new behavior can been disabled for a particular project by
setting the `AndroidEnableAssemblyCompression` MSBuild property to `false` in
the _.csproj_ file:

```xml
<PropertyGroup>
  <AndroidEnableAssemblyCompression>false</AndroidEnableAssemblyCompression>
</PropertyGroup>
```

> [!NOTE]
> This feature is intended to replace the older **Bundle assemblies into native
> code** Visual Studio Enterprise feature for purposes of app size savings.  The
> `AndroidEnableAssemblyCompression` property takes precedence if both features
> are enabled.  Project authors who no longer need the **Bundle assemblies into
> native code** feature enabled can now disable it or remove the
> `BundleAssemblies` MSBuild property from the _.csproj_ file:
>
> ```diff
>  <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|AnyCPU' ">
>    <DebugSymbols>True</DebugSymbols>
>    <DebugType>portable</DebugType>
>    <Optimize>True</Optimize>
>    <OutputPath>bin\Release\</OutputPath>
>    <DefineConstants>TRACE</DefineConstants>
>    <ErrorReport>prompt</ErrorReport>
>    <WarningLevel>4</WarningLevel>
>    <AndroidManagedSymbols>true</AndroidManagedSymbols>
>    <AndroidUseSharedRuntime>False</AndroidUseSharedRuntime>
>    <AndroidLinkMode>SdkOnly</AndroidLinkMode>
>    <EmbedAssembliesIntoApk>True</EmbedAssembliesIntoApk>
> -  <BundleAssemblies>true</BundleAssemblies>
>  </PropertyGroup>
> ```

#### Background information

For comparison, for the small test Xamarin.Forms application, the **Bundle
assemblies into native code** feature increases the APK size from about 23
megabytes to about 26 megabytes while increasing the time to display the
first page of the app from about 780 milliseconds to about 850 milliseconds 
in the least favorable configuration. Size comparison is for an application
which enables **all** of the ABIs supported by Xamarin.Android.  It needs to
be noted that in this scenario, the **Bundle assemblies into native code**
feature will add a copy of the shared library with compressed assemblies per 
ABI, thus the size increase. The new compression shares all the compressed
assemblies between all the ABIs, thus enabling a new one won't cause the APK
to grow. If sizes are compared for application shipping just a single ABI, the
**Bundle assemblies into native code** feature decreases the the APK size from
around 16 megabytes to around 7.5 megabytes, while the new scheme decreases the
size to around 8 megabytes. Display times are not affected by the number of ABIs
present in the APK.

[lz4]: https://github.com/lz4/lz4
